"""
Some objects you can use for the HQPorner API.
"""


class Sort:
    ALL_TIME = "all-time"
    WEEK = "week"
    MONTH = "month"


class Category:
    QUALITY_HD = "1080p-porn"
    ANAL = "anal-sex-hd"
    QUALITY_4K = "4k-porn"
    MILF = "milf"
    LESBIAN = "lesbian"
    CREAMPIE = "creampie"
    FPS_60 = "60fps-porn"
    BIG_TITS = "big-tits"
    TEEN_PORN = "teen-porn"
    POV = "pov"
    THREESOME = "threesome"
    ASIAN = "asian"  # Favourite :D
    OLD_AND_YOUNG = "old-and-young"
    EBONY = "ebony"
    BIG_ASS = "big-ass"  # Cringe
    INTERRACIAL = "interracial"
    MATURE = "mature"
    SQUIRT = "squirt"
    SEX_MASSAGE = "porn-massage"
    CASTING = "casting"
    AMATEUR = "amateur"
    GANGBANG = "gangbang"
    STOCKINGS = "stockings"
    BIG_DICK = "big-dick"
    LATINA = "latina"
    BABE = "babe"
    GROUP_SEX = "group-sex"
    RUSSIAN = "russian"
    MASTURBATION = "masturbation"
    HAIRY_PUSSY = "hairy-pussy"
    UNIFORMS = "uniforms"
    SHEMALE = "shemale"
    BLONDE = "blonde"
    ORGASM = "orgasm"
    PICKUP = "pickup"
    SEX_PARTY = "sex-parties"
    BDSM = "bdsm"
    PUBLIC = "public"
    JAPANESE = "japanese-girls-porn"
    REDHEAD = "redhead"
    ORGY = "orgy"
    FETISH = "fetish"
    BLOWJOB = "blowjob"
    SMALL_TITS = "small-tits"
    BRUNETTE = "brunette"
    UNDRESSING = "undressing"
    CUMSHOT = "cumshot"
    OUTDOOR = "outdoor"
    DEEPTHROAT = "deepthroat"
    BONDAGE = "bondage"
    SHAVED_PUSSY = "shaved_pussy"
    BISEXUAL = "bisexual"
    HENTAI = "hentai"
    HANDJOB = "handjob"
    PUSSY_LICKING = "pussy-licking"
    FISTING = "fisting"
    MOANING = "moaning"
    VINTAGE = "vintage"
    TATTOOED = "tattooed"
    BEACH_PORN = "beach-porn"
    VIBRATOR = "vibrator"
    FINGERING = "fingering"
    SQUEEZING_TITS = "squeezing-tits"
    LONG_HAIR = "long-hair"
